aboutsummaryrefslogtreecommitdiffstats
path: root/src/libmdsserver/util.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libmdsserver/util.h')
-rw-r--r--src/libmdsserver/util.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/libmdsserver/util.h b/src/libmdsserver/util.h
index 30b2139..77fdf4b 100644
--- a/src/libmdsserver/util.h
+++ b/src/libmdsserver/util.h
@@ -121,10 +121,11 @@ int full_write(int fd, const char* buffer, size_t length);
/**
* Read a file completly and ignore interruptions
*
* @param fd The file descriptor
* @return The content of the file, you will need to free it. `NULL` on error.
*/
-char* full_read(int fd);
+char* full_read(int fd, size_t* length);
/**
* Check whether a string begins with a specific string,
@@ -121,10 +121,11 @@ int full_write(int fd, const char* buffer, size_t length);
* Read a file completly and ignore interruptions
*
- * @param fd The file descriptor
- * @return The content of the file, you will need to free it. `NULL` on error.
+ * @param fd The file descriptor
+ * @param length Output parameter for the length of the file, may be `NULL`
+ * @return The content of the file, you will need to free it. `NULL` on error.
*/